@@ -38,7 +38,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <gnome.h>
+#include <unistd.h>
 #include "utils.h"
 #include "properties.h"
 
@@ -202,11 +202,11 @@ editor_hig_attach_row (GtkWidget *table, gchar *text, GtkWidget *control, int ro
 static gboolean stock_test_url_added = FALSE;
 static GtkStockItem test_url_items [] =
 {
-	{ GTKHTML_STOCK_TEST_URL, N_("_Visit..."), 0, 0, GETTEXT_PACKAGE }
+	{ GTKHTML_STOCK_TEST_URL, N_("_Test URL..."), 0, 0, GETTEXT_PACKAGE }
 };
 
 void
-editor_check_stock ()
+editor_check_stock (void)
 {
 	if (!stock_test_url_added) {
 		GdkPixbuf *pixbuf;
