@@ -261,10 +261,8 @@ static HTMLObject *
 op_copy (HTMLObject *self, HTMLObject *parent, HTMLEngine *e, GList *from, GList *to, guint *len)
 {
 	HTMLObject *dup, *clue;
-	GtkHTML *html;
 
 	dup = html_object_dup (self);
-	html = GTK_HTML (HTML_IFRAME (dup)->html);
 	clue = GTK_HTML (HTML_IFRAME (self)->html)->engine->clue;
 	GTK_HTML (HTML_IFRAME (dup)->html)->engine->clue =
 		html_object_op_copy (clue, dup, GTK_HTML (HTML_IFRAME (self)->html)->engine,
@@ -465,15 +463,13 @@ save (HTMLObject *s,
 
 		if (state->error || 
 		    !html_engine_save_output_buffer (state,
-						     html_engine_save_buffer_peek_text (buffer),
+						     (gchar *) html_engine_save_buffer_peek_text (buffer),
 						     html_engine_save_buffer_peek_text_bytes (buffer))) {
 			html_engine_save_buffer_free (buffer, TRUE);
 			return FALSE;
 		}
 		html_engine_save_buffer_free (buffer, TRUE);
 	} else {
-		HTMLEngine *e = GTK_HTML (iframe->html)->engine;
-
 		if (!html_engine_save_output_string (state, "<IFRAME SRC=\"%s\"", iframe->url))
 			 return FALSE;
         
@@ -518,7 +514,7 @@ save_plain (HTMLObject *s,
 		html_object_save_plain (e->clue, buffer, requested_width);
 		if (state->error || 
 		    !html_engine_save_output_buffer (state,
-						     html_engine_save_buffer_peek_text (buffer),
+						     (gchar *) html_engine_save_buffer_peek_text (buffer),
 						     html_engine_save_buffer_peek_text_bytes (buffer))) {
 			html_engine_save_buffer_free (buffer, TRUE);
 			return FALSE;
